@@ -9,6 +9,7 @@
 '''
 
 from typing import Type
+import os
 
 from .server import ServerMiddleware
 from .client import ClientMiddleware
@@ -18,9 +19,13 @@ from ..config import Config
 
 
 def init_server(tasks: Type[Tasks], config=Config()):
+    os.makedirs(config.middleware_path, exist_ok=True)
     server = ServerMiddleware(tasks, config)
+    for i in range(config.middleware_num):
+        middleware_path_num = os.path.join(config.middleware_path, f"./middleware_{i}.db")
+        server.initialize_database(middleware_path_num)
     client = ClientMiddleware(Services, config)
-    return server, client, client.services.create_send_message(config.middleware_path)
+    return server, client, client.services.create_send_message(config)
 
 def start_server(server: ServerMiddleware, client: ClientMiddleware):
     server.start_server()
@@ -31,4 +36,4 @@ def start_server(server: ServerMiddleware, client: ClientMiddleware):
 def stop_server(server: ServerMiddleware, client: ClientMiddleware):
     server.stop_server()
     client.stop_client()
-    return 0
\ No newline at end of file
+    return 0
